openCashDrawer method
Open the cash drawer.
Sends a command to the connected cash drawer to open it.
Implementation
Future<void> openCashDrawer() async {
IminPrinterPlatform.instance.openCashDrawer();
}
Open the cash drawer.
Sends a command to the connected cash drawer to open it.
Future<void> openCashDrawer() async {
IminPrinterPlatform.instance.openCashDrawer();
}