MethodChannelIminPrinter class

An implementation of IminPrinterPlatform that uses method channels.

Inheritance

Constructors

MethodChannelIminPrinter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearLCDScreen() → Future<String>
override
fullCut() → Future<String>
override
getBrandName() → Future<String>
override
getModelName() → Future<String>
override
getPlatformVersion() → Future<String?>
override
getStatus() → Future<String>
override
initLCDManager() → Future<String>
override
initPrinter(PrintSizeImin printSizeImin) → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCashDrawer() → Future<String>
override
partialCut() → Future<String>
override
print2ColumnsText(List<String> listText, PrintStyle printStyle) → Future<String>
override
printBitmap(Uint8List bytes) → Future<String>
override
printBitmapBase64(String base64) → Future<String>
override
printBytes(Uint8List bytes) → Future<String>
override
printQR(String data, int size) → Future<String>
override
printText(String text, PrintStyle printStyle) → Future<String>
override
sendBitmapBase64LCDScreen(String base64) → Future<String>
override
setPrintSize(PrintSizeImin printSizeImin) → Future<String?>
override
setStyle(PrintStyle printStyle) → Future<String>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited