PrintStyle class

Constructors

PrintStyle({PrintStyleAlign textAlign = PrintStyleAlign.left, int textSize = 19, PrintStyleFont fontStyle = PrintStyleFont.regular})
const

Properties

fontStyle → PrintStyleFont
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → PrintStyleAlign
final
textSize → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited